@@ -1021,6 +1021,9 @@ class Update(MethodsInterface):
                              'cl_update_rep_name',
                              'cl_update_branch',
                              'cl_update_binhost_list',
+                             'cl_update_binhost_unstable_list',
+                             'cl_update_binhost_stable_set',
+                             'cl_update_binhost_stable_opt_set',
                              'cl_update_branch_name',
                              'cl_profile_system',
                              'cl_update_rep'):
@@ -1183,13 +1186,21 @@ class Update(MethodsInterface):
                                                  int(new_ts) > int(old_ts)):
                     ini = SystemIni(self.clVars)
                     ini.setVar('update', {'last_update': new_ts})
+        if self.clVars.Get('cl_action') == 'sync':
+            value = self.clVars.GetBool('cl_update_binhost_stable_set')
+            new_value = self.clVars.GetBool('cl_update_binhost_stable_opt_set')
+            if value != new_value:
+                self.clVars.Write(
+                    'cl_update_binhost_stable_set',
+                    self.clVars.Get('update.cl_update_binhost_stable_opt_set'),
+                    location="system")
         return True
 
     def message_binhost_changed(self):
         if self.refresh_binhost:
             self.printWARNING(_("Update server was changed to %s") %
                               self.clVars.Get('cl_update_binhost'))
-        elif self.clVars.GetBool('update.cl_update_binhost_recheck_set'):
+        else:
             self.printSUCCESS(_("Update server %s") %
                               self.clVars.Get('cl_update_binhost'))
         return True
@@ -1205,6 +1216,7 @@ class Update(MethodsInterface):
             dv.flIniFile()
             changes = False
             for varname in ('update.cl_update_binhost_list',
+                            'update.cl_update_binhost_unstable_list',
                             'update.cl_update_binhost_timestamp_path',
                             'cl_update_binhost_revision_path'):
                 new_value = dv.Get(varname)
@@ -1213,8 +1225,10 @@ class Update(MethodsInterface):
                     changes = True
                 self.clVars.Set(varname, new_value, force=True)
             if not changes:
+                self.clVars.Delete('cl_update_binhost', location="system")
                 raise UpdateError(_("Update server is unavailable"))
         except DataVarsError:
+            self.clVars.Delete('cl_update_binhost', location="system")
             raise UpdateError(_("Update server is unavailable"))
         return True
 
