@@ -64,7 +64,8 @@ class Wsdl(WsdlBase):
             # описание груп (список лямбда функций)
             'groups': [
                 lambda group: group(_("Update the system"),
-                                    normal=(),
+                                    normal=(
+                                        'cl_update_binhost_stable_opt_set',),
                                     expert=(
                                     'cl_update_sync_only_set',
                                     'cl_update_other_set',
